# alacrity

[![PyPI version](https://badge.fury.io/py/alacrity.svg)](https://badge.fury.io/py/alacrity)
[![Build Status](https://travis-ci.org/vishnuvardhan-kumar/alacrity.svg?branch=master)](https://travis-ci.org/vishnuvardhan-kumar/alacrity)
[![CodeFactor](https://www.codefactor.io/repository/github/vishnuvardhan-kumar/alacrity/badge/master)](https://www.codefactor.io/repository/github/vishnuvardhan-kumar/alacrity/overview/master)
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=flat-square)](http://makeapullrequest.com)


Quickstart your Python project with a single handy command.

`pip install alacrity`

To use alacrity, just type in a terminal:

`alacrity`

Answer some questions interactively, and poof, your package structure is ready.

Based on the [sample Python package](https://github.com/kennethreitz/samplemod) structure by Kenneth Reitz.

Tested to work on :
 - Windows (and Cygwin)
 - Linux (anything except Android Terminal Emulators)

A sample alacrity flow:

![Image](https://github.com/vishnuvardhan-kumar/alacrity/blob/master/alacrity/tests/scr.png?raw=true)
